@@ -7,6 +7,8 @@
 import re
 
 import bs4
+ 
+from HTMLParser import HTMLParser 
 
 from .util import force_decode, between_two_tags
 
@@ -62,6 +64,6 @@ def html_minify(html_code, ignore_comments=True):
 
     for tag in EXCLUDE_TAGS:
         for index, e in enumerate(exclude_tags[tag]):
-            content = content.replace(TAGS_PATTERN % (tag, index, tag), e)
+            content = content.replace(TAGS_PATTERN % (tag, index, tag), HTMLParser().unescape(e))
 
     return content
